/************************************************************************/
/*  SEGY Descriptive reel header (3200 bytes).				*/
/************************************************************************/
typedef struct SegyDReelHead {
    char cards[80][40];
} SEGYDREELHEAD;

/************************************************************************/
/*  SEGY binary reel header (400 bytes).				*/
/************************************************************************/
typedef struct SegyBReelHead {                    
    int		kjob;		/* Job identification number.		*/
    int		kline;		/* Line number.				*/
    int		kreel;		/* Reel number.				*/
    short int	kntr;		/* Number of data traces per record.	*/
    short int	kaux;		/* Number of auxiliary traces per record.*/
    short int	sr;		/* Sample interval of this reel's data	*/
				/* in microseconds.			*/
    short int	kfldsr;		/* Sample interval of original field	*/
				/* recording in microseconds.		*/
    short int	knsamp;		/* Number of samples per trace for this	*/
				/* reel's data.				*/
    short int	kfsamp;		/* Number of samples per trace in	*/
				/* original field recording.		*/
    short int	kform;		/* Data sample format code:		*/
				/*     1 = 32-bit IBM floating point	*/
				/*     2 = 32-bit fixed-point (integer)	*/
				/*     3 = 16-bit fixed-point (integer)	*/
				/*     4 = 32-bit fixed-point with	*/
				/*         gain code (integer)		*/
    short int	kmfold;		/* CDP fold (expected number of data	*/
				/* traces per ensemble).		*/
    short int	ksort;		/* Trace sorting code:			*/
				/*     1 = as recorded			*/
				/*     2 = CDP ensemble			*/
				/*     3 = single fold continuous profile*/
				/*     4 = horizontally stacked		*/
    short int	kvsum;		/* Vertical sum code			*/
				/*     (1 = no sum, 2 = two sum, ...)	*/
    short int	kswfrs;		/* Sweep frequency at start in Hertz.	*/
    short int	kswfre;		/* Sweep frequency at end in Hertz.	*/
    short int	kmssw;		/* Sweep length in milliseconds.	*/
    short int	kswtyp;		/* Sweep type code:			*/
				/*     1 = linear			*/
				/*     2 = parabolic			*/
				/*     3 = exponential			*/
				/*     4 = other			*/
    short int	kswtr;		/* Trace number of sweep channel.	*/
    short int	kmsbst;		/* Sweep trace taper length at start	*/
				/* in milliseconds.			*/
    short int	kmsest;		/* Sweep trace taper length at end	*/
				/* in milliseconds.			*/
    short int	ksttyp;		/* Taper type code:			*/
				/*     1 = linear			*/
				/*     2 = cosine squared		*/
				/*     3 = other			*/
    short int	kcorcd;		/* Correlated data traces		*/
				/*     (1 = no, 2 = yes).		*/
    short int	kbgrcd;		/* Binary gain recovered		*/
				/*     (1 = yes, 2 = no).		*/
    short int	kartyp;		/* Amplitude recovery method code:	*/
				/*     1 = one				*/
				/*     2 = spherical divergence		*/
				/*     3 = AGC				*/
				/*     4 = other			*/
    short int	kunits;		/* Measurement system			*/
				/*     (1 = meters, 2 = feet).		*/
    short int	kpol;		/* Impulse signal polarity		*/
				/*     (increase in pressure or upward	*/
				/*     geophone case movement gives	*/
				/*     1=negative or 2=positive number).*/
    short int	kvpol;		/* Vibratory polarity code		*/
				/* (seismic lags pilot signal by):	*/
				/*     1 = 337.5 to 22.5 degrees	*/
				/*     2 = 22.5 to 67.5 degrees		*/
				/*     3 = 67.5 to 112.5 degrees	*/
				/*     4 = 112.5 to 157.5 degrees	*/
				/*     5 = 157.5 to 202.5 degrees	*/
				/*     6 = 202.5 to 247.5 degrees	*/
				/*     7 = 247.5 to 292.5 degrees	*/
				/*     8 = 292.5 to 337.5 degrees	*/
    /* Additional unused elements used by LBL.				*/
    short int	nyear;		/* year					*/
    short int	nday;		/* day of year				*/
    short int	nhour;		/* hour					*/
    short int	nmin;		/* minute				*/
    short int	nsec;		/* second				*/
    short int	nmsec;		/* millisecond				*/
    char	dum[328];	/* Unused elements.			*/
} SEGYBREELHEAD;
